@@ -24,7 +24,9 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <config.h>
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 #include <gmpc/plugin.h>
 #include <libmpd/debug_printf.h>
