@@ -79,6 +79,7 @@ void jamendo_db_init()
 void jamendo_db_open()
 {
     gchar *path = NULL;
+    gchar *final = NULL;
 
 
     /**
@@ -90,11 +91,10 @@ void jamendo_db_open()
         jamendo_sqlhandle = NULL;
     }
 
-    g_free(path);
-    path = gmpc_get_user_path("jamendo.sqlite3"); 
+//    final = g_get_user_cache_dir();
+    path = gmpc_get_cache_directory("jamendo.sqlite3");//g_build_filename(final, "gmpc", "jamendo.sqlite3", NULL);
     sqlite3_open(path, &(jamendo_sqlhandle));
     g_free(path);
-
 }
 /* FIXME */
 gboolean jamendo_db_has_data()
