@@ -25,14 +25,40 @@
 #include <gmpc/misc.h>
 #include <libmpd/libmpd-internal.h>
 #include <sqlite3.h>
-#include <libxml/xmlreader.h>
-#include <libxml/tree.h>
 #include <playlist3-messages.h>
 #include "magnatune.h"
 
-static void magnatune_cleanup_xml();
 static sqlite3 *magnatune_sqlhandle = NULL;
 
+static gchar *user_name = NULL;
+static gchar *user_password = NULL;
+
+void magnatune_set_user_password(const gchar *name, const gchar *password)
+{
+    if(user_name) g_free(user_name);
+    user_name = NULL;
+
+    if(name && strlen(name) > 0)
+        user_name = gmpc_easy_download_uri_escape(name);
+
+    if(user_password) g_free(user_password);
+    user_password = NULL;
+
+    if(password && strlen(password) > 0)
+        user_password = gmpc_easy_download_uri_escape(password);
+}
+
+static gchar *magnatune_get_url(const gchar *n)
+{
+    if(user_name != NULL && user_password != NULL)
+    {
+        int len = strlen(n);
+        if (len > 4)
+            return g_strdup_printf("http://%s:%s@stream.magnatune.com/all/%*.*s_nospeech.mp3",user_name, user_password, len - 4, len - 4, n);
+
+    }
+    return g_strdup_printf("http://he3.magnatune.com/all/%s",n);
+}
 
 void magnatune_db_destroy(void)
 {
@@ -51,6 +77,7 @@ void magnatune_db_init()
 void magnatune_db_open()
 {
     gchar *path = NULL;
+    const gchar *final = NULL;
 
 
     /**
@@ -62,8 +89,7 @@ void magnatune_db_open()
         magnatune_sqlhandle = NULL;
     }
 
-    g_free(path);
-    path = gmpc_get_user_path("magnatune.sqlite3"); 
+    path = gmpc_get_cache_directory("magnatune.sqlite3");// g_build_filename(final, "gmpc", "magnatune.sqlite3", NULL);
     sqlite3_open(path, &(magnatune_sqlhandle));
     g_free(path);
 
@@ -93,14 +119,13 @@ gboolean magnatune_db_has_data()
 MpdData * magnatune_db_get_genre_list()
 {
     MpdData *list = NULL;
-    xmlNodePtr **root;
-    xmlNodePtr **cur;
-    int i;
+    int i,r;
 
     char *query = sqlite3_mprintf("SELECT genre from 'genres' group by genre");
     sqlite3_stmt *stmt = NULL;
     const char *tail;
-    int r = sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
+    GTimer *timer = g_timer_new();
+    r = sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
     if(r ==SQLITE_OK) {
         while((r = sqlite3_step(stmt)) == SQLITE_ROW)
         {
@@ -113,17 +138,22 @@ MpdData * magnatune_db_get_genre_list()
 
     sqlite3_finalize(stmt);
     sqlite3_free(query);
-    return misc_mpddata_remove_duplicate_songs(list); 
+    g_debug("%f s elapsed getting genres\n", g_timer_elapsed(timer,NULL));
+    g_timer_reset(timer);
+    list = misc_mpddata_remove_duplicate_songs(list); 
+    g_debug("%f s elapsed unique genres list\n", g_timer_elapsed(timer,NULL));
+    g_timer_destroy(timer);
+    return list;
 }
 
 void magnatune_db_load_data(const char *data, const goffset length)
 {
     gchar *error = NULL;
-    xmlTextReaderPtr reader = NULL;
     gchar *path;
 
 
-    path = gmpc_get_user_path("magnatune.sqlite3"); 
+//    const gchar *final = g_get_user_cache_dir();
+    path = gmpc_get_cache_directory("magnatune.sqlite3");//g_build_filename(final, "gmpc", "magnatune.sqlite3", NULL);
     if(magnatune_sqlhandle)
     {
         int status = sqlite3_close(magnatune_sqlhandle);
@@ -135,7 +165,6 @@ void magnatune_db_load_data(const char *data, const goffset length)
         }
         magnatune_sqlhandle = NULL;
     }
-//    if(gmpc_easy_download("http://he3.magnatune.com/info/sqlite_magnatune.db", dld))
     if(data){
         GError *error = NULL;
         gssize size= (gssize)length;
@@ -144,11 +173,8 @@ void magnatune_db_load_data(const char *data, const goffset length)
             gchar *temp =g_strdup_printf("Failed to store magnatune db: %s\n", error->message);
             playlist3_show_error_message(temp, ERROR_WARNING);
             g_free(temp);
-            printf("%s\n", error->message);
             g_error_free(error);
         }
-        printf("%s\n", path);
-  //      gmpc_easy_download_clean(dld);
     }
     /* open the db if it is closed */
     if(!magnatune_sqlhandle) {
@@ -169,23 +195,24 @@ void magnatune_db_load_data(const char *data, const goffset length)
     if(error)printf("%i: %s",__LINE__, error);
     sqlite3_exec(magnatune_sqlhandle, "CREATE INDEX genresAlbumname ON genres(albumname);", NULL, NULL, &error);
     if(error)printf("%i: %s",__LINE__, error);
+    sqlite3_exec(magnatune_sqlhandle, "CREATE INDEX genresGenrename ON genres(genre);", NULL, NULL, &error);
+    if(error)printf("%i: %s",__LINE__, error);
     sqlite3_exec(magnatune_sqlhandle, "CREATE INDEX albumsAlbumname ON albums(albumname);", NULL, NULL, &error);
     if(error)printf("%i: %s",__LINE__, error);
 
-//    g_idle_add(magnatune_end_download, NULL);
     g_free(path);
 }
 
 MpdData * magnatune_db_get_artist_list(char *wanted_genre)
 {
     MpdData *list = NULL;
-    xmlNodePtr root;
-    xmlNodePtr cur;
+    int r;
     /** check if there is data */
     char *query = sqlite3_mprintf("SELECT albumname from 'genres' WHERE genre=%Q", wanted_genre);
     sqlite3_stmt *stmt = NULL;
     const char *tail;
-    int r = sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
+    GTimer *timer = g_timer_new();
+    r = sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
     if(r ==SQLITE_OK) {
         while((r = sqlite3_step(stmt)) == SQLITE_ROW)
         {
@@ -208,20 +235,26 @@ MpdData * magnatune_db_get_artist_list(char *wanted_genre)
     }
     sqlite3_finalize(stmt);
     sqlite3_free(query);
-    return misc_mpddata_remove_duplicate_songs(list);
+    g_debug("%f s elapsed getting genres\n", g_timer_elapsed(timer,NULL));
+    g_timer_reset(timer);
+    list = misc_mpddata_remove_duplicate_songs(list);
+
+    g_debug("%f s elapsed unique artist list\n", g_timer_elapsed(timer,NULL));
+    g_timer_destroy(timer);
+    return list;
 }
 
 MpdData *magnatune_db_get_album_list(char *wanted_genre,char *wanted_artist)
 {
+    int r;
     MpdData *list = NULL;
-    xmlNodePtr **root;
-    xmlNodePtr **cur;
     /** check if there is data */
 
     char *query = sqlite3_mprintf("SELECT albumname from 'albums' WHERE artist=%Q",wanted_artist);
     sqlite3_stmt *stmt = NULL;
     const char *tail;
-    int r = sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
+    GTimer *timer = g_timer_new();
+    r = sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
     if(r ==SQLITE_OK) {
         while((r = sqlite3_step(stmt)) == SQLITE_ROW)
         {
@@ -244,6 +277,8 @@ MpdData *magnatune_db_get_album_list(char *wanted_genre,char *wanted_artist)
     }
     sqlite3_finalize(stmt);
     sqlite3_free(query);
+    g_debug("%f s elapsed listing albums songs\n", g_timer_elapsed(timer,NULL));
+    g_timer_destroy(timer);
     return mpd_data_get_first(list); 
 }
 
@@ -295,6 +330,50 @@ static char *__magnatune_get_genre_name(const char *album)
     sqlite3_free(query);
     return retv;
 }
+static MpdData *__magnatune_get_data_album_from_genre(const char *genre, gboolean exact)
+{
+    MpdData *list = NULL;
+    char *query = NULL;
+    sqlite3_stmt *stmt = NULL;
+    const char *tail;
+    int r = 0;
+    GTimer *timer = g_timer_new();
+    if(exact)
+    {
+        query =  sqlite3_mprintf("SELECT songs.albumname,duration,number,desc,mp3 from 'songs' JOIN 'genres' ON songs.albumname = genres.albumname " 
+        "WHERE genres.genre=%Q",genre);
+    }else{
+        query =  sqlite3_mprintf("SELECT songs.albumname,duration,number,desc,mp3 from 'songs' JOIN 'genres' ON songs.albumname = genres.albumname "
+        "WHERE genres.genre LIKE '%%%%%q%%%%'",genre);
+    }
+    r=sqlite3_prepare_v2(magnatune_sqlhandle, query, -1,  &stmt,  &tail);
+    if(r ==SQLITE_OK) {
+        while((r = sqlite3_step(stmt)) == SQLITE_ROW)
+        {
+            gchar *temp = gmpc_easy_download_uri_escape(sqlite3_column_text(stmt,4));
+            list = mpd_new_data_struct_append(list);
+            list->type = MPD_DATA_TYPE_SONG;
+            list->song = mpd_newSong();
+            list->song->album = g_strdup(sqlite3_column_text(stmt,0));
+            list->song->artist = __magnatune_get_artist_name(list->song->album);
+            list->song->genre = __magnatune_get_genre_name(list->song->album);
+            list->song->title= g_strdup(sqlite3_column_text(stmt,3));
+            list->song->track = g_strdup(sqlite3_column_text(stmt,2));
+            list->song->time = sqlite3_column_int(stmt,1);
+            list->song->file = magnatune_get_url(temp);
+            g_free(temp);
+        }
+    }else{
+        g_warning("Sqlite error: %s\n", tail);
+    }
+
+    sqlite3_finalize(stmt);
+    sqlite3_free(query);
+    g_debug("%f s elapsed getting album songs from genre\n", g_timer_elapsed(timer,NULL));
+    g_timer_destroy(timer);
+    return list;
+}
+
 static MpdData *__magnatune_get_data_album(const char *album, gboolean exact)
 {
     MpdData *list = NULL;
@@ -302,6 +381,7 @@ static MpdData *__magnatune_get_data_album(const char *album, gboolean exact)
     sqlite3_stmt *stmt = NULL;
     const char *tail;
     int r = 0;
+    GTimer *timer = g_timer_new();
     if(exact)
     {
         query =  sqlite3_mprintf("SELECT songs.albumname,duration,number,desc,mp3 from 'songs' " 
@@ -324,12 +404,17 @@ static MpdData *__magnatune_get_data_album(const char *album, gboolean exact)
             list->song->title= g_strdup(sqlite3_column_text(stmt,3));
             list->song->track = g_strdup(sqlite3_column_text(stmt,2));
             list->song->time = sqlite3_column_int(stmt,1);
-            list->song->file = g_strdup_printf("http://he3.magnatune.com/all/%s",temp);
+            list->song->file = magnatune_get_url(temp);
             g_free(temp);
         }
     }
+    else{
+        g_warning("Sqlite error: %s\n", tail);
+    }
     sqlite3_finalize(stmt);
     sqlite3_free(query);
+    g_debug("%f s elapsed getting album songs\n", g_timer_elapsed(timer,NULL));
+    g_timer_destroy(timer);
     return list;
 }
 static gchar ** __magnatune_get_albums(const char *genre, const char *artist, gboolean exact)
@@ -379,15 +464,17 @@ static gchar ** __magnatune_get_albums(const char *genre, const char *artist, gb
 MpdData* magnatune_db_get_song_list(const char *wanted_genre,const char *wanted_artist, const char *wanted_album, gboolean exact)
 {
     MpdData *data = NULL;
-    xmlNodePtr * root;
-    xmlNodePtr * cur;
     char *query;
 
     if(!wanted_genre && !wanted_artist && !wanted_album) return NULL;
 
+    GTimer *timer = g_timer_new();
     if(wanted_album) /* album seems to be unique */
     {
         data = __magnatune_get_data_album(wanted_album, exact);
+    }else if (wanted_genre && !wanted_artist)
+    {
+        data = __magnatune_get_data_album_from_genre(wanted_genre, exact);
     }
     else 
     {
@@ -404,6 +491,8 @@ MpdData* magnatune_db_get_song_list(const char *wanted_genre,const char *wanted_
         }
     }
 
+    g_debug("%f s elapsed song list\n", g_timer_elapsed(timer,NULL));
+    g_timer_destroy(timer);
     return mpd_data_get_first(data);
 }
 
@@ -431,7 +520,7 @@ MpdData * magnatune_db_search_title(const gchar *title)
             list->song->title= g_strdup(sqlite3_column_text(stmt,3));
             list->song->track = g_strdup(sqlite3_column_text(stmt,2));
             list->song->time = sqlite3_column_int(stmt,1);
-            list->song->file = g_strdup_printf("http://he3.magnatune.com/all/%s",temp);
+            list->song->file = magnatune_get_url(temp);
             g_free(temp);
         }
     }
